Failed attempts for governments added
[shipsimu.git] / index.php
index 9ad3a004105a12bfcd8a035112395d454870a184..cf898bf7dbb77fe8967570faa0a48e168b4c4a5c 100644 (file)
--- a/index.php
+++ b/index.php
@@ -4,7 +4,7 @@ define('DEVELOPER', true);
 //xdebug_start_trace();
 /**
  * The main class with the entry point to the whole application. This class
- * "emulates" Java(tm)'s entry point call. Additionally it covers local
+ * "emulates" Java's entry point call. Additionally it covers local
  * variables from outside access to prevent possible attacks on uninitialized
  * local variables.
  *
@@ -29,7 +29,12 @@ define('DEVELOPER', true);
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
-class ApplicationEntryPoint {
+final class ApplicationEntryPoint {
+       /**
+        * Core path
+        */
+       private static $corePath = '';
+
        /**
         * The instances we want to remove after all is done
         *
@@ -49,12 +54,13 @@ class ApplicationEntryPoint {
        /**
         * The application's emergency exit
         *
* @param       $message        The optional message we shall output on exit
* @param       $code           Error code from exception
* @param       $extraData      Extra information from exceptions
         * @return      void
         */
-       public static function app_die ($message = "", $code = false, $extraData = "") {
+       public static function app_die ($message = '', $code = false, $extraData = '', $silentMode = false) {
                // Is this method already called?
                if (defined('EMERGENCY_EXIT_CALLED')) {
                        // Then output the text directly
@@ -67,70 +73,79 @@ class ApplicationEntryPoint {
                // Is a message set?
                if (empty($message)) {
                        // No message provided
-                       $message = "No message provided!";
-               }
+                       $message = 'No message provided!';
+               } // END - if
+
+               // Get config instance
+               $configInstance = FrameworkConfiguration::getInstance();
+
+               // Do we have debug installation?
+               if (($configInstance->getConfigEntry('product_install_mode') == 'productive') || ($silentMode === true)) {
+                       // Abort here
+                       die();
+               } // END - if
 
                // Get some instances
-               $tpl = FrameworkConfiguration::getInstance()->readConfig('template_class');
+               $tpl = FrameworkConfiguration::getInstance()->getConfigEntry('template_class');
                $lang = LanguageSystem::getInstance();
-               $io = FileIoHandler::getInstance();
 
                // Get response instance
                $responseInstance = ApplicationHelper::getInstance()->getResponseInstance();
 
                // Is the template engine loaded?
-               if ((class_exists($tpl)) && (is_object($lang)) && (is_object($io))) {
+               if ((class_exists($tpl)) && (is_object($lang))) {
                        // Use the template engine for putting out (nicer look) the message
                        try {
                                // Get the template instance from our object factory
-                               $tplEngine = ObjectFactory::createObjectByConfiguredName('template_class', array(FrameworkConfiguration::getInstance()->readConfig('tpl_base_path'), $lang, $io));
-                       } catch (BasePathIsEmptyException $e) {
-                               die(sprintf("[Main:] Could not initialize template engine for this reason: <strong>%s</strong>",
-                                       $e->getMessage()
-                               ));
-                       } catch (InvalidBasePathStringException $e) {
-                               die(sprintf("[Main:] Could not initialize template engine for this reason: <strong>%s</strong>",
-                                       $e->getMessage()
-                               ));
-                       } catch (BasePathIsNoDirectoryException $e) {
-                               die(sprintf("[Main:] Could not initialize template engine for this reason: <strong>%s</strong>",
-                                       $e->getMessage()
-                               ));
-                       } catch (BasePathReadProtectedException $e) {
-                               die(sprintf("[Main:] Could not initialize template engine for this reason: <strong>%s</strong>",
+                               $templateInstance = ObjectFactory::createObjectByName($tpl, array(ApplicationHelper::getInstance()));
+                       } catch (FrameworkException $e) {
+                               die(sprintf("[Main:] Could not initialize template engine for reason: <span class=\"exception_reason\">%s</span>",
                                        $e->getMessage()
                                ));
                        }
 
-                       // Backtrace holen und aufbereiten
+                       // Get and prepare backtrace for output
                        $backtraceArray = debug_backtrace();
-                       $backtrace = "";
-                       foreach ($backtraceArray as $key=>$trace) {
+                       $backtrace = '';
+                       foreach ($backtraceArray as $key => $trace) {
                                if (!isset($trace['file'])) $trace['file'] = __FILE__;
-                               if (!isset($trace['line'])) $trace['line'] = 5;
+                               if (!isset($trace['line'])) $trace['line'] = __LINE__;
                                if (!isset($trace['args'])) $trace['args'] = array();
                                $backtrace .= "<span class=\"backtrace_file\">".basename($trace['file'])."</span>:".$trace['line'].", <span class=\"backtrace_function\">".$trace['function']."(".count($trace['args']).")</span><br />";
                        } // END - foreach
 
+                       // Init application instance
+                       $appInstance = null;
+
+                       // Is the class there?
+                       if (class_exists('ApplicationHelper')) {
+                               // Get application instance
+                               $appInstance = ApplicationHelper::getInstance();
+
+                               // Assign application data
+                               $templateInstance->assignApplicationData($appInstance);
+                       } // END - if
+
                        // Assign variables
-                       $tplEngine->assignVariable('message', $message);
-                       $tplEngine->assignVariable('code', $code);
-                       $tplEngine->assignVariable('extra', $extraData);
-                       $tplEngine->assignVariable('backtrace', $backtrace);
-                       $tplEngine->assignVariable('total_includes', ClassLoader::getInstance()->getTotal());
-                       $tplEngine->assignVariable('total_objects', ObjectFactory::getTotal());
+                       $templateInstance->assignVariable('message', $message);
+                       $templateInstance->assignVariable('code', $code);
+                       $templateInstance->assignVariable('extra', $extraData);
+                       $templateInstance->assignVariable('backtrace', $backtrace);
+                       $templateInstance->assignVariable('total_includes', ClassLoader::getInstance()->getTotal());
+                       $templateInstance->assignVariable('total_objects', ObjectFactory::getTotal());
+                       $templateInstance->assignVariable('title', $lang->getMessage('emergency_exit_title'));
 
                        // Load the template
-                       $tplEngine->loadCodeTemplate('emergency_exit');
+                       $templateInstance->loadCodeTemplate('emergency_exit');
 
                        // Compile the template
-                       $tplEngine->compileTemplate();
+                       $templateInstance->compileTemplate();
 
                        // Compile all variables
-                       $tplEngine->compileVariables();
+                       $templateInstance->compileVariables();
 
                        // Transfer data to response
-                       $tplEngine->transferToResponse($responseInstance);
+                       $templateInstance->transferToResponse($responseInstance);
 
                        // Flush the response
                        $responseInstance->flushBuffer();
@@ -145,30 +160,43 @@ class ApplicationEntryPoint {
                }
        }
 
+       /**
+        * Determines the correct absolute path for all includes only once per run.
+        * Other calls of this method are being "cached".
+        *
+        * @return      $basePath       Base path (core) for all includes
+        */
+       protected static function detectCorePath () {
+               // Is it not set?
+               if (empty(self::$corePath)) {
+                       // Auto-detect our core path
+                       self::$corePath = str_replace("\\", '/', dirname(__FILE__));
+               } // END - if
+
+               // Return it
+               return self::$corePath;
+       }
+
        /**
         * The application's main entry point. This class isolates some local
         * variables which shall not become visible to outside because of security
         * concerns. We are doing this here to "emulate" the well-known entry
-        * point in Java(tm).
+        * point in Java.
         *
         * @return      void
         */
        public static function main () {
-               // Some non-global common arrays we need...
-               global $_SERVER;
-
                // Load config file
-               require(dirname(__FILE__) . '/inc/config.php');
+               require(self::detectCorePath() . '/inc/config.php');
 
                // Load all include files
-               require(PATH . 'inc/includes.php');
+               require($cfg->getConfigEntry('base_path') . 'inc/includes.php');
 
                // Load all framework classes
-               require(PATH . 'inc/classes.php');
+               require($cfg->getConfigEntry('base_path') . 'inc/classes.php');
 
                // Include the application selector
-               require(PATH . 'inc/selector.php');
-
+               require($cfg->getConfigEntry('base_path') . 'inc/selector.php');
        } // END - main()
 
 } // END - class
@@ -49,12 +54,13 @@ class ApplicationEntryPoint {
         * The application's emergency exit
         *
-        * @param       $message        The optional message we shall output on exit
-        * @param       $code           Error code from exception
-        * @param       $extraData      Extra information from exceptions
+        * @param       $message                The optional message we shall output on exit
+        * @param       $code                   Error code from exception
+        * @param       $extraData              Extra information from exceptions
+        * @param       $silentMode             Wether not silent mode is turned on
         * @return      void
         */